==> haskell-microlens-aeson-2.2.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.2.0.1
id: microlens-aeson-2.2.0.1-353bYDRx9LJF6eAMxEgzek
key: microlens-aeson-2.2.0.1-353bYDRx9LJF6eAMxEgzek
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
           Copyright (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
stability: provisional
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
author: Colin Woodbury
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
abi: 778949f853c35f96251fa874dd8a763f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/microlens-aeson-2.2.0.1
hs-libraries: HSmicrolens-aeson-2.2.0.1-353bYDRx9LJF6eAMxEgzek
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    bytestring-0.10.8.1 microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.2.0.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.2.0.1
id: microlens-aeson-2.2.0.1-Ewm4Unguygf23XcUrnWeNV
key: microlens-aeson-2.2.0.1-Ewm4Unguygf23XcUrnWeNV
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
           Copyright (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
stability: provisional
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
author: Colin Woodbury
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
abi: ef8ed5b4aa32392c03ce1e623378d585
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/microlens-aeson-2.2.0.1
hs-libraries: HSmicrolens-aeson-2.2.0.1-Ewm4Unguygf23XcUrnWeNV
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    bytestring-0.10.8.1 microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
